==> SAGElyzer_1.3.0.tar.gz: SAGElyzer/R/dbTools.R <==
# This function makes a connection to a given database using the
# arguments passed as a list.
#
# args - a list containing the arguments presented as name and value
#        pairs. Valid element names include "dbname", "user", "password",
#        "host", "hostaddr", and "port".
# dbObj - a binding object for a given dbms (e. g. PgSQL() for postgreSQL).
#
# Copyright 2002, J. Zhang. All rights reserved.
#

# Make db connection under Unix
con4Win <- function(args){
#    require(RODBC) || stop("Package RODBC unavailable")
    return(odbcConnect(args[["DSN"]]))
}
# Make db connection under Unix
con4Unix <- function(args){
#    require(Rdbi) || stop("Package Rdbi unavailable")
    FORMAL <- c("host", "hostaddr", "port", "dbname", "user",
               "password", "dbObj")
    # filters out args not needed for making connection
    args <- args[intersect(names(args), FORMAL)]
    return(do.call("dbConnect", args))
}
# Make a connection to a database
makeConnection <- function(args){
    switch(.Platform$OS.type,
           "windows" = return(con4Win(args)),
           "unix" = return(con4Unix(args)),
           stop("Unknown OS system"))
}
# Execute a query
executeQuery <- function(sqlStat, conn, noReturn = FALSE){
    switch(.Platform$OS.type,
           "windows" = return(sqlQuery(conn, sqlStat)),
           "unix" = return(query4Unix(sqlStat, conn, noReturn)),
           stop("Unknown OS system"))
}
# Does query under Unix
query4Unix <- function(sqlStat, conn, noReturn = FALSE){
    queryResult <- dbSendQuery(conn, sqlStat)
    if(!noReturn){
        queryResult <- dbGetResult(queryResult)
        return(queryResult)
    }
}
# Close a connection
closeConn <- function(conn){
    options(show.error.messages = FALSE)
    switch(.Platform$OS.type,
           "windows" = try(odbcClose(conn)),
           "unix" = try(dbDisconnect(conn)),
           stop("Unknown OS system"))
    options(show.error.messages = TRUE)
}

tableExists <- function(conn, tableName){
    if(.Platform$OS.type == "windows"){
        options(show.error.messages = FALSE)
        tryMe <- try(odbcTableExists(conn, tableName))
        options(show.error.messages = TRUE)
        if(inherits(tryMe, "try-error")){
            return(FALSE)
        }else{
            return(TRUE)
        }
    }else{
        relNames <- dbListTables(conn)$relname
        if(is.element(tableName, relNames)){
            return(TRUE)
        }else{
            return(FALSE)
        }
    }
}

==> SAGElyzer_1.10.0.tar.gz: SAGElyzer/R/dbTools.R <==
# This function makes a connection to a given database using the
# arguments passed as a list.
#
# args - a list containing the arguments presented as name and value
#        pairs. Valid element names include "dbname", "user", "password",
#        "host", "hostaddr", and "port".
# dbObj - a binding object for a given dbms (e. g. PgSQL() for postgreSQL).
#
# Copyright 2002, J. Zhang. All rights reserved.
#

# Make db connection under Unix
con4Win <- function(args){
#    require(RODBC) || stop("Package RODBC unavailable")
    return(odbcConnect(args[["DSN"]]))
}
# Make db connection under Unix
con4Unix <- function(args){
#    require(Rdbi) || stop("Package Rdbi unavailable")
    FORMAL <- c("host", "hostaddr", "port", "dbname", "user",
               "password", "dbObj")
    # filters out args not needed for making connection
    args <- args[intersect(names(args), FORMAL)]
    return(do.call("dbConnect", args))
}
# Make a connection to a database
makeConnection <- function(args){
    switch(.Platform$OS.type,
           "windows" = return(con4Win(args)),
           "unix" = return(con4Unix(args)),
           stop("Unknown OS system"))
}
# Execute a query
executeQuery <- function(sqlStat, conn, noReturn = FALSE){
    switch(.Platform$OS.type,
           "windows" = return(sqlQuery(conn, sqlStat)),
           "unix" = return(query4Unix(sqlStat, conn, noReturn)),
           stop("Unknown OS system"))
}
# Does query under Unix
query4Unix <- function(sqlStat, conn, noReturn = FALSE){
    queryResult <- dbSendQuery(conn, sqlStat)
    if(!noReturn){
        results <- dbGetResult(queryResult)
        dbClearResult(queryResult)
        return(results)
    }else{
        dbClearResult(queryResult)
        return(invisible())
    }
}
# Close a connection
closeConn <- function(conn){
    options(show.error.messages = FALSE)
    switch(.Platform$OS.type,
           "windows" = try(odbcClose(conn)),
           "unix" = try(dbDisconnect(conn)),
           stop("Unknown OS system"))
    options(show.error.messages = TRUE)
}

tableExists <- function(conn, tableName){
    if(.Platform$OS.type == "windows"){
        options(show.error.messages = FALSE)
        tryMe <- try(odbcTableExists(conn, tableName))
        options(show.error.messages = TRUE)
        if(inherits(tryMe, "try-error")){
            return(FALSE)
        }else{
            return(TRUE)
        }
    }else{
        relNames <- dbListTables(conn)$relname
        if(is.element(tableName, relNames)){
            return(TRUE)
        }else{
            return(FALSE)
        }
    }
}
